local AddonName, Addon = ...

-- Lib
local L = Addon.Libs.L
local DGL = Addon.Libs.DGL
local DCL = Addon.Libs.DCL

-- Upvalues
local tonumber, max = tonumber, math.max

-- Game
local Game = Addon.Game
local DB = Addon.DB

-- Debug
local function debug(...) Addon.Core:Debug("Game", ...) end

-- Consts
local HIGH_SCORE_FORMAT = DCL:ColorString(strupper(L.HIGH_SCORE_TEXT), DCL.CSS.Ivory).."|n%s"

-- Variables
local currentScore = 0

-- ============================================================================
-- UIFrame
-- ============================================================================

Game.UIFrame = CreateFrame("Frame", nil, Game.Frame)
Game.UIFrame:SetFrameLevel(Game.Frame:GetFrameLevel()+1)
Game.UIFrame:SetAllPoints()

Game.UIFrame.ScoreText = Game.UIFrame:CreateFontString(nil, "ARTWORK")
Game.UIFrame.ScoreText:SetFont("Fonts\\FRIZQT__.TTF", 24)
Game.UIFrame.ScoreText:SetText(0)
Game.UIFrame.ScoreText:SetPoint("BOTTOM", 0, 35)

Game.UIFrame.HighScoreText = Game.UIFrame:CreateFontString(nil, "ARTWORK")
Game.UIFrame.HighScoreText:SetFont("Fonts\\FRIZQT__.TTF", 32)
Game.UIFrame.HighScoreText:SetPoint("TOP", 0, -15)

Game.UIFrame.HelpText = Game.UIFrame:CreateFontString(nil, "ARTWORK")
Game.UIFrame.HelpText:SetFont("Fonts\\FRIZQT__.TTF", 10)
Game.UIFrame.HelpText:SetPoint("BOTTOM", 0, 15)

-- ============================================================================
-- General Functions
-- ============================================================================

function Game:GetScore() return currentScore end
function Game:Score() self:SetScore(currentScore + 1) end
function Game:SetScore(score)
  currentScore = max(0, score)
  self.UIFrame.ScoreText:SetText(currentScore)
end

function Game:SetHighScore(score)
  DB.Global.HighScore = max(0, score)
  self.UIFrame.HighScoreText:SetText(
    (score > 0) and
    HIGH_SCORE_FORMAT:format(score) or
    L.NO_HIGH_SCORE_TEXT
  )
  
end

function Game:GameOver()
  if (self:GetState() ~= self.States.Playing) then return end
  if (currentScore >= DB.Global.HighScore) then self:SetHighScore(currentScore)
   if (currentScore == 0) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac ist nicht stolz auf dich","GUILD")     
		elseif (currentScore > 200) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Flap Flap Flap!","GUILD") 
		elseif (currentScore > 100) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac kann es kaum glauben","GUILD")
		elseif (currentScore > 90) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac ist crass stolz auf dich","GUILD")
		elseif (currentScore > 80) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac ist richtig stolz auf dich","GUILD")
		elseif (currentScore > 70) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac ist sehr stolz auf dich","GUILD")
		elseif (currentScore > 60) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac ist stolz auf dich","GUILD")
		elseif (currentScore > 50) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac ist stolz auf dich. PS: Shinn ist nicht nice!","GUILD")
		elseif (currentScore > 30) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac ist ein wenig stolz auf dich","GUILD") 
		elseif (currentScore > 20) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac ist minimal stolz auf dich","GUILD")
		elseif (currentScore >= 1) then SendChatMessage("hat einen neuen Rekord in FlappySyrac erreicht:" .. currentScore .. " Punkte! Syrac ist immernoch nicht stolz auf dich","GUILD") 	
	end  
  end
  self:SetState(self.States.Death)
  Addon.Player:Die()
end

-- Set initial state
Game:SetState(Game.States.StartGame)

-- Create window
DGL:CreateWindow(Addon.Game, AddonName, Addon.GAME_ICON)

-- Called whenever the game window is closed.
function Game:OnWindowClosed()
  if (self:GetState() == self.States.Playing) then
    self:PushState(self.States.Paused)
  end
end
